BaseDbModel mixin

@date 27/4/22 describe:

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
primaryKeyAndValue() → Map<String, dynamic>
模型的key跟value值
toJson() → Map<String, dynamic>
模型转换成Json
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited